@@ -1224,7 +1224,7 @@ class Builder(Update):
                 fn = line_split[0 + column_shift]
                 caps = line_split[1 + column_shift:]
                 fn = fn[len(chroot_path):]
-                f.write("%s %s\n"% (fn, " ".join(x.strip() for x in caps)))
+                f.write("%s %s\n"% (fn, " ".join(x.rstrip(",") for x in caps)))
         return True
 
     def clear_file_capabilities(self):
