@@ -23,10 +23,10 @@ from calculate.lib.utils.files import FilesError
 from calculate.lib.variables.system import RootType
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
-from ..datavars import BuilderError
 from calculate.lib.utils.git import GitError
 from calculate.install.distr import DistributiveError, IsoDistributive
-from calculate.builder.variables.action import Actions
+from ..datavars import BuilderError
+from ..variables.action import Actions
 
 _ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
