@@ -329,7 +329,8 @@ class Wsdl(WsdlBase):
             'setvars': {'cl_action!': BuilderActions.Restore},
             # описание груп (список лямбда функций)
             'groups': [
-                lambda group: group(_("Break the Build"),
+                # there used to be a typo: Break the Build instead of Restore the Build
+                lambda group: group(_("Restore the Build"),
                                     normal=('cl_builder_broken_id',),
                                     expert=('cl_templates_locate',
                                             'cl_verbose_set',
